Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Heap ¶
type Heap struct {
Data []*Node
// contains filtered or unexported fields
}
@Min Heap
func (*Heap) Extract ¶
Extract function retrives the root node by swapping root node with the last node and removing it from the last index Last node is then heapifyed Down
Click to show internal directories.
Click to hide internal directories.